@@ -1,8 +1,10 @@
 #ifndef ___INCLUDES_H__
 #define ___INCLUDES_H__
 /*
- * Nessus system includes 
+ * OpenVAS system includes 
  */
+#include "system.h"
+
 
 #ifdef _CYGWIN_
 #undef _WIN32
@@ -193,13 +195,12 @@
 #include <limits.h>
 #endif
 
-#include <openssl/ssl.h>
-#include <openssl/x509.h>
+#include <gnutls/gnutls.h>
 
 /*
  * Threads management
  *
- * Nessus is currently able to deal with 
+ * OpenVAS might be able to deal with
  * 3 kinds of threads API :
  *
  * - the POSIX Threads
@@ -208,7 +209,7 @@
  *
  */
 
-#ifdef NESSUSNT
+#ifdef OPENVASNT
 #define USE_NT_THREADS
 #else
 #ifndef USE_PTHREADS
@@ -260,10 +261,7 @@
 #endif
 
 #include <ntcompat.h>
-#include <libnessus.h>
-#ifndef __HARG_INTERNAL__
-#include <harglists.h>
-#endif
+#include <arglists.h>
 
 #ifdef HAVE_SHL_LOAD	/* I love HPUX (jh) */
 #undef dlopen
