@@ -21,8 +21,4 @@
 int attack_host(char *, struct context *);
 void attack_handler();
 
-#ifdef ENABLE_SAVE_TESTS
-void restore_attack(char *, struct context *);
-#endif
-
 #endif /* _ATTACK_H */
