@@ -359,8 +359,8 @@ parse_plugin (char * buf)
   char * cve  = NULL;
   char * bid  = NULL;
   char * xref = NULL;
-  char * sign_key_ids;
-  char * script_tags;
+  char * sign_key_ids = NULL;
+  char * script_tags = NULL;
 
   gboolean failed = FALSE;
   char * space = strstr(buf, " ");
@@ -491,6 +491,8 @@ parse_plugin (char * buf)
   if(cve) efree(&cve);
   if(bid) efree(&bid);
   if(xref) efree(&xref);
+  if(sign_key_ids) efree(&sign_key_ids);
+  if(script_tags) efree(&script_tags);
 
   return NULL;
 }
@@ -564,13 +566,6 @@ comm_parse_preference (struct context *context, struct arglist *serv_prefs,
   if ((!a) || (!b) || (!c))
   {
     // It is a server preference or info
-#ifdef ENABLE_SAVE_TESTS
-    if (!strcmp(pref, "ntp_save_sessions"))
-      context->sessions_saved = 1;
-    else if (!strcmp(pref, "ntp_detached_sessions"))
-      context->detached_sessions_saved = 1;
-    else
-#endif
       if (!strncmp(pref, "server_info_", strlen("server_info_")))
       {
 	if (serv_infos == NULL)
@@ -790,11 +785,6 @@ comm_get_preferences (struct context *context)
   struct arglist *serv_prefs, *serv_infos, *plugs_prefs = NULL;
   struct arglist *prefs = context->prefs;
 
-#ifdef ENABLE_SAVE_TESTS
-  context->sessions_saved = 0;
-  context->detached_sessions_saved = 0;
-#endif
-
   serv_prefs = arg_get_value (prefs, "SERVER_PREFS");
   if (!serv_prefs)
     {
@@ -2117,62 +2107,6 @@ comm_get_plugins (struct context *context)
   return result;
 }
 
-
-/*-------------------------------------------------------------------------
-			Sessions management
----------------------------------------------------------------------------*/
-
-/**
- * @brief Does the server support sessions saving?
- */
-int
-comm_server_restores_sessions (struct context *context)
-{
-#ifdef ENABLE_SAVE_TESTS
-  return context->sessions_saved;
-#else
-  return 0;
-#endif
-}
-
-
-GHashTable *
-comm_get_sessions (struct context * context)
-{
-  char buff[32768];
-  GHashTable* sessions = NULL;
-
-  network_printf (context->socket, "CLIENT <|> SESSIONS_LIST <|> CLIENT\n");
-  network_gets (context->socket, buff, sizeof (buff));
-  if (!strcmp (buff, "SERVER <|> SESSIONS_LIST\n"))
-    {
-      sessions = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, g_free);
-      while (!strstr (buff, "<|> SERVER"))
-        {
-          char *t;
-
-          network_gets (context->socket, buff, sizeof (buff));
-          t = strchr (buff, ' ');
-          if (t && !strstr (buff, "<|> SERVER"))
-            {
-              if (buff[strlen (buff) - 1] == '\n')
-                buff[strlen (buff) - 1] = '\0';
-              t[0] = 0;
-              t++;
-              g_hash_table_insert (sessions, g_strdup (buff), g_strdup (t));
-            }
-        }
-    }
-  return sessions;
-}
-
-
-void
-comm_restore_session (struct context * context, char *name)
-{
-  network_printf(context->socket, "CLIENT <|> SESSION_RESTORE <|> %s <|> CLIENT\n", name);
-}
-
 /*-------------------------------------------------------------------------
                Requesting Dependencies and Certificates
 ---------------------------------------------------------------------------*/
