@@ -1093,11 +1093,6 @@ connect_to_scanner (struct context * context)
     plugin_cache_write(context, context->plugins_md5sum);
   }
 
-#ifdef ENABLE_SAVE_TESTS
-  if(comm_server_restores_sessions(context))
-    context->sessions = comm_get_sessions(context);
-#endif
-
   efree(&passwd);
   return(NULL);
 }
@@ -1245,8 +1240,6 @@ main (int argc, char * argv[])
   static gchar *config_file = NULL;
   static gchar *output_type = NULL;
   static gboolean sqlize_output = FALSE;
-  static gboolean list_sessions = FALSE;
-  static gboolean restore_session = FALSE;
   static gboolean convert_filtered = FALSE;
   static gboolean convert_drop_fp  = FALSE;
   static gboolean convert_drop_ni  = FALSE;
@@ -1279,8 +1272,6 @@ main (int argc, char * argv[])
     { "convert-drop-no-info", 'N', 0, G_OPTION_ARG_NONE, &convert_drop_ni, N_("Drop issues with \"No Information\" during report conversion to html"), NULL },
     { "dont-check-ssl-cert", 'x', 0, G_OPTION_ARG_NONE, &dont_check_ssl_cert, N_("Override SSL \"paranoia\" question preventing OpenVAS-Client from checking certificates"), NULL },
     { "sqlize-output", 'S', 0, G_OPTION_ARG_NONE, &sqlize_output, N_("Issue SQL output for -p and -P (experimental)"), NULL },
-    { "list-sessions", 's', 0, G_OPTION_ARG_NONE, &list_sessions, N_("List sessions"), N_("<host> <port> <user> <pass>") },
-    { "restore-session", 'R', 0, G_OPTION_ARG_NONE, &restore_session, N_("Restore session"), N_("<sessionid> <host> <port> <user> <pass> <result-file>") },
     { G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_STRING_ARRAY, &remaining_options, NULL, NULL },
     { NULL }
   };
@@ -1332,21 +1323,6 @@ main (int argc, char * argv[])
     quiet_mode = TRUE;
   }
 
-#ifdef ENABLE_SAVE_TESTS
-  if (restore_session)
-  {
-    if(remaining_options != NULL)
-      // TODO: Is remaining_options[0] enough? restore_session seems to completely ignore session_id anyway.
-      session_id = g_strdup(remaining_options[0]);
-    else
-    {
-      printf(_("The session ID is required to restore a session.\n")); /* RATS: ignore, the non-constant format string comes from a trusted source. */
-      printf(_("Please use %s --help for more information.\n"), myself); /* RATS: ignore, the non-constant format string comes from a trusted source. */
-      exit(1);
-    }
-  }
-#endif
-
   F_quiet_mode   = quiet_mode;
   F_show_pixmaps = show_pixmaps;
 
@@ -1399,27 +1375,6 @@ main (int argc, char * argv[])
 #define BATCH_USAGE "batch mode and <host> <port> <user> <pass> "
 #define BATCH_ARGC 3
 
-#ifdef ENABLE_SAVE_TESTS
-  if(list_sessions && (remaining_options_count < BATCH_ARGC) && !quiet_mode)
-  {
-    fprintf(stderr, _("list-sessions requires %s\n"), BATCH_USAGE);
-    exit(1);
-  }
-
-  if(restore_session && (remaining_options_count < BATCH_ARGC) && !quiet_mode)
-  {
-    fprintf(stderr, _("restore-session requires -q %s <result>\n"), BATCH_USAGE);
-    exit(1);
-  }
-
-  if(restore_session && list_sessions)
-  {
-    fprintf(stderr, _("--restore-session and --list-sessions are mutually exclusive\n"));
-    exit(1);
-  }
-#endif
-
-
   if(remaining_options_count >= BATCH_ARGC || quiet_mode)
   {
     signal(SIGINT, sighand_exit);
@@ -1519,36 +1474,7 @@ main (int argc, char * argv[])
 
 #define NUM_ARGS 5
 
-#ifndef ENABLE_SAVE_TESTS
-    if (remaining_options_count != NUM_ARGS)
-    {
-      if(!((remaining_options_count == NUM_ARGS - 2) && make_config_file))
-      {
-        printf(_("Batch mode requires login information.\n")); /* RATS: ignore, the non-constant format string comes from a trusted source. */
-        printf(_("Please use %s --help for more information.\n"), myself); /* RATS: ignore, the non-constant format string comes from a trusted source. */
-        exit(0);
-      }
-    }
-#else
-    if(list_sessions)
-    {
-      if (remaining_options_count != NUM_ARGS - 2)
-      {
-        fprintf(stderr, "%s" BATCH_USAGE "\n",
-                _("list-sessions only requires "));
-        exit(1);
-      }
-    }
-    else if(restore_session)
-    {
-      if (remaining_options_count != NUM_ARGS - 1)
-      {
-        fprintf(stderr, "%s" BATCH_USAGE " <result-file>\n",
-                _("restore-session only requires "));
-        exit(1);
-      }
-    }
-    else if(list_prefs || list_plugins)
+    if(list_prefs || list_plugins)
     {
       if (batch_mode == NULL || remaining_options_count < NUM_ARGS - 2)
       {
@@ -1564,8 +1490,6 @@ main (int argc, char * argv[])
       exit(0);
     }
 
-#endif /* !ENABLE_SAVE_TESTS */
-
     /* next arguments: SERVER PORT */
     cli_args_server(cli, batch_mode);
     cli_args_port(cli, atoi(remaining_options[0]));
@@ -1613,14 +1537,6 @@ main (int argc, char * argv[])
 
     if(!make_config_file)
     {
-      if(restore_session)
-      {
-        cli_args_results(cli, remaining_options[3]);
-      }
-      else
-      {
-        if(!list_sessions)
-        {
           char * t = remaining_options[3];
           if(t)
             cli_args_target(cli, t);
@@ -1635,8 +1551,6 @@ main (int argc, char * argv[])
           {
             fprintf(stderr, _("Missing parameter\n"));
           }
-        }
-      }
     }
 
     cli_args_output(cli, output_type);
@@ -1648,22 +1562,6 @@ main (int argc, char * argv[])
         openvas_exit(1);
       }
 
-#ifdef ENABLE_SAVE_TESTS
-    if(list_sessions)
-    {
-      cli_list_sessions(cli);
-      close_stream_connection(Context->socket);
-      Context->socket = -1;
-      if (log_config) free_log_configuration (log_config);
-      openvas_exit(0);
-    }
-    else if(restore_session)
-    {
-      cli_restore_session(cli, session_id);
-    }
-    else
-#endif
-
     if(make_config_file)
     {
       if(!preferences_generate_new_file(Global, NULL))
